from setuptools import setup, find_packages
from pathlib import Path

# Read the README file
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

setup(
    name="cardisk",
    version="0.4.6",
    description="A modern, intuitive Python framework for building USSD applications with FastAPI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Jose Machava",
    author_email="",
    url="https://github.com/jaymachava/cardisk",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "fastapi>=0.115.0",
        "uvicorn>=0.20.0",
        "typer>=0.6.0",
        "httpx>=0.24.0",
        "pytest>=7.0.0",
        "prometheus_client>=0.15.0",
    ],
    entry_points={
        "console_scripts": [
            "cardisk=cardisk.cli:app",
        ],
    },
    python_requires=">=3.9",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Framework :: FastAPI",
    ],
    keywords="ussd, fastapi, framework, mobile, telecommunications",
)
